/*!
 * \file macmd.c
 * \author Benjamin Zhai (benjamin.zhai@sensima.com)
 * \version 1.1
 * \date 20140108
 * \brief MA Command utility.
 *
 * Copyright  2013-2014 Sensima Technology SA \n
 * Company Confidential \n
 *
 * Project: MA-FTDI USB \n
 * Module: MA sensor command utility using FTDI USB \n
 *
 * Revision History: \n
 * 0.1     - rev 340   - 20140402 - Initial version \n

 * \todo

 */

/******************************************************************************/
/*                           Include files                                    */
/******************************************************************************/
/* Standard C libraries */
#include<stdio.h>
#include<stdlib.h>
/* OS specific libraries */
#ifdef _WIN32
#include<windows.h>
#endif

#ifndef DEBUG
#define DEBUG 0
#endif

/* Custom libraries */
#include "parser.h"
#include "ma_api.h"

#define EQUIV_FIFO_DEPTH 2500
#define MAX_FIFO_BYTESIZE EQUIV_FIFO_DEPTH*3


/******************************************************************************/
/*                      Public function definitions                                */
/******************************************************************************/


/*!
 * \brief Main function / Entry point to the sample application
 *
 * This function is the entry point to the sample application. It opens the channel, reads data
 * from the MA sensor via FTDI-USB and prints the data to the screen or to the specified file
 *
 * \param[in] argc, argv
 * \return Returns 0 for success
 * For detailed help type:
 * \code
 * $maread --help
 * \endcode
 * Example Usage:
 * \code
 * $maread -v -f output.txt -c1 -oc -rh -e -s250
 * \endcode
 * \sa
 * \note
 * \warning
 */
int main(int argc, char *argv[])
{
    uint8 *buffer; //Arbitrary memory to be malloc()'d
    FILE *outfile;
    FILE *outerror;
    int remaining_size;
    int buffer_write_count = 0;
	FT_HANDLE ftHandle;
	GEN_PARAM GenParam;
	PARSER_PARAM ParserParam;
	ChannelConfig channelConf;

	GenParam.channel = 1;
	GenParam.muted = 1;
	GenParam.spimode = 0;
	GenParam.baudrate = 25000000;
	ParserParam.trnsfr16b = 0;

	
    //MA_AutoChannel(&GenParam);
	
	
    // Allocate memory
    buffer = (uint8 *) malloc(12);
    if (buffer == NULL)
    {
        printf("ERROR: Could not allocate memory\n");
        exit(1);
    }

    // Parse command line arguments
    arg_parser(&GenParam,&ParserParam,argc,argv);

    // Initialising MA communication interface
    MA_Open(&ftHandle,GenParam,&channelConf);
    
	MA_Cmd(ftHandle,ParserParam.data_in);
	
	if (ParserParam.trnsfr16b)
	{
		buffer[0] = (uint8) ((ParserParam.data_in>>8)&0xff);
		buffer[1] = (uint8) ((ParserParam.data_in)&0xff);
		FTDI_WriteStream(ftHandle, buffer, 2);
	}
	else
	{
		FTDI_ReadStream(ftHandle, buffer, 12);
   
	   int i;

			for (i = 0; i < 12; i++)
			{
				printf("Data: "BYTETOBINARYPATTERN" "BYTETOBINARYPATTERN" "BYTETOBINARYPATTERN"\n", \
						BYTETOBINARY(buffer[3*i]), BYTETOBINARY(buffer[3*i+1]), BYTETOBINARY(buffer[3*i+2]));
			}
	}

    // Release unused resources
    free(buffer);
    MA_Close(ftHandle); // Destructor of MA_Open()


    return 0;
}

