/*!
 * \file parser.h
 * \author Benjamin Zhai (benjamin.zhai@sensima.com)
 * \version 1.1
 * \date 20140108
 * \brief Main program argument parser
 *
 * Copyright © 2013-2014 Sensima Technology SA \n
 * Company Confidential \n
 *
 * Project: MA-FTDI USB \n
 * Module: MA sensor communication utility using FTDI USB \n
 *
 * Revision History: \n
 * 0.1     - rev ?     - 20131024 - Initial version \n
 * 0.2     - rev 8     - 20131025 - Added argument parser options \n
 *                                  Updated error report format \n
 * 0.2.1   - rev       - 20131025 - Added include guard \n
 *                                  Improved debug code syntax \n
 *                                  Added doxygen style comments \n
 *                                  Changed filename \n
 * 0.2.2   - rev 23    - 20131030 - Corrected decimal format bugs \n
 * 0.3     - rev 40    - 20131104 - Changed SPI to mode 0 \n
 * 0.4     - rev 49    - 20131104 - Changed program name to "maread" \n
 *                                  Made SPI mode configurable \n
 * 0.5     - rev 64    - 20131112 - Added plain output \n
 * 0.6     - rev 87    - 20131118 - Added baudrate option \n
 * 0.9     - rev 123   - 20131211 - Merged pre-release\n
 * 1.0     - rev 136   - 20131212 - Release \n
 * 1.02    - rev 143   - 20131216 - Added auto channel detection \n
 * 1.03    - rev 144   - 20121216 - Modified debug behaviour \n
 * 1.04    - rev 146   - 20121216 - Updated help messages \n
 * 1.05    - rev 148   - 20121216 - Default behaviour defined \n
 * 1.06    - rev 150   - 20131216 - Corrected bitfield write \n
 * 1.10    - rev 165   - 20140108 - Radix bug fixes \n
 * 1.9.3   - rev 210   - 20140129 - 2.0 Pre-release \n
 * \todo
 */
#ifndef __PARSER_H__
#define __PARSER_H__

#ifndef DEBUG
#define DEBUG 0
#endif

/* Standard C libraries */
#include<stdio.h>
#include<stdlib.h>
#include<string.h>
#include "ma_api.h"
#include "build_defs.h"

typedef struct ParserParam_t
{
	int data_in;
	int trnsfr16b;
} PARSER_PARAM;
/*!
 * \brief Main function's argument parser
 *
 * This function parses the input arguments of the main function
 * and writes resulting configuration to global variables
 *
 * \param[in] argc, argv
 * \return Returns 0 for success
 * Example Usage:
 * \code
 * arg_parser(argc,argv);
 * \endcode
 * \sa
 * \note
 * \warning
 */
int arg_parser(GEN_PARAM* GenParam, PARSER_PARAM* ParserParam, int argc, char *argv[]);

#endif